<?php

namespace Scriptor\Module\SimpleComponents;

use Imanager\Item;
use Imanager\TemplateParser;
use Scriptor\Core\Module;

class Component extends Module
{
	public $content;
	
	/**
	 * @var Imanager\TemplateParser $templateParser instance 
	 */
	private $templateParser;

	/**
	 * It simply adopts the item's attributes 
	 * to be able to process them better.
	 */
	public function __construct(Item $item)
	{
		foreach($item as $key => $val) $this->$key = $val;
	}

	/**
	 * Creates an instance of the TemplateParser
	 */
	private function loadTemplateParser()
    {
        $this->templateParser = new TemplateParser();
	}

	/**
	 * Tries to parse the passed content (string),
	 * $tvs placeholders will replaced with values.
	 * 
	 * @param string $content - String to be parsed
	 * @param array $tvs - Placeholders and replacement
	 */
	private function replaceTVs(string $content, array $tvs)
    {
        if(!$this->templateParser) $this->loadTemplateParser();

        return $this->templateParser->render($content, $tvs);
    }
	
	/**
	 * Renders the component.
	 * 
	 *  @param array $vars - Variables to replace the placeholders
	 */
	public function render(array $vars = [])
	{
		if(!empty($vars)) {
            $content = htmlspecialchars_decode($this->replaceTVs($this->content, $vars));
        } else {
            $content = htmlspecialchars_decode($this->content);
        }

        return $content;
	}
}