<?php

namespace Scriptor\Modules\SimpleComponents;

use Imanager\Category;
use Imanager\Field;
use Imanager\Util;
use Scriptor\Core\Helper;
use Scriptor\Core\Module;
use Scriptor\Core\Scriptor;

class SimpleComponents extends Module
{
    /**
	 * Module version 
	 * 
	 * Use ~~ echo SimpleComponents::VERSION; ~~~
	 * to get the current module version
	 */
    const VERSION = '1.5.1';

	private $compEditor;

	private $components;

	/**
	 * @var boolean - The purpose of this variable is likely to keep track of 
	 * whether the class has been initialized or not. Used to ensure that a 
	 * class is only initialized once, even if it is instantiated multiple times.
	 */
	private static $initialized = false;

    public function init() 
    {
		if (!self::$initialized) {
			parent::init();
			Scriptor::load(__DIR__.'/Components.php');
			Scriptor::load(__DIR__.'/ComponentsEditor.php');

			if (defined('IS_EDITOR') && $this->segments->get(0) == 'SimpleComponents') {
					$this->compEditor = new ComponentsEditor();
					$this->compEditor->init();
			} else {
				$this->components = new Components();
				$this->components->init();
			}
			self::$initialized = true;
		}
    }

	public function execute()
	{
		$this->compEditor->execute();
		$this->pageContent = $this->compEditor->pageContent;
		$this->pageTitle = $this->compEditor->pageTitle;
		$this->breadcrumbs = $this->compEditor->breadcrumbs;
	}

	public function getComponent(string $name)
	{
		return $this->components->get($name);
	}

	public static function moduleInfo() : array
	{
		return [
			'name' => 'SimpleComponents',
			'menu' => 'cm_list_menu',
            'position' => 4,
            'active' => true,
            'auth' => true,
            'autoinit' => true,
			'display_type' => [
				'sidebar'
			],
			'icon' => 'gg-extension',
            'description' => 'This module allows you to create dynamic reusable template elements within the Scriptor Editor. '.
				'<a href="https://scriptor-cms.info/extensions/extensions-modules/simplecomponents/">More information</a>',
			'version' => self::VERSION,
			'author' => 'Bigin',
			'author_website' => 'https://ehret-studio.com'
		];
	}

	public static function moduleHooks() : array
	{
		return [
			'Editor::beforeExecute' => [
				[
					'module' => 'SimpleComponents',
					'method' => 'loadResources'
				]
			]
		];
	}

	/**
	 * Inserts Reostatic style sheet to the head section of Scriptor editor.
	 */
	public function loadResources()
	{
		$this->addResource(
			'link', ['rel' => 'stylesheet',
				'href' => dirname($this->siteUrl).
				'/site/modules/SimpleComponents/css/styles.css'], 'header'
		);
	}

	/**
     * Installs a new category and makes the module ready for use.
     * 
     * @return bool 
     */
    public function install() : bool
    {
		if (!self::$initialized) $this->init();

        $components = new Category();
        $components->set('name', 'Components')
             ->save();

        if ($components) {
            $newField = new Field($components->id);
            $newField->set('type', 'longtext')
                    ->set('name', 'content')
                    ->save();
                  
            $newField = new Field($components->id);
            $result = $newField->set('type', 'text')
                    ->set('name', 'slug')
                    ->save();

			if ($result) {
				$this->msgs[] = [
					'type' => 'success',
					'value' => $this->i18n['cm_success_created_cat']
				];

				return true;
			}

        }

		$this->msgs[] = [
			'type' => 'error',
			'value' => $this->i18n['cm_error_cat_creating']
		];

		return false;
    }

	public function uninstall() : bool
	{
		if (!self::$initialized) $this->init();

		$components = $this->imanager->getCategory('name=Components');
		if ($components) {
			if ($this->imanager->remove($components)) {
				return true;
			}
		}
		return false;
	}

}